@@ -34,9 +34,9 @@ class HomeAssistantCog(commands.Cog):
     @app_commands.command(name="alarm")
     @app_commands.choices(choices=get_functions(ha.Alarm))
     @commands.has_role("Shiny")
-    async def testing(self, context: discord.Interaction, choices: str):
+    async def arm(self, context: discord.Interaction, choices: str):
         # print(await self.get_functions())
-        testing = ha.InputBoolean("testing")
+        testing = ha.Alarm("system")
         testing_function = getattr(testing, choices)
         testing_function()
         await context.response.send_message(f"Testing is {choices}ing")
