@@ -39,35 +39,32 @@ class Vacuum(HomeAssistant):
         self.client.get_domain(self.domain).start(entity_id=self.entity_id)
 
     def stop(self):
+        """Return vacuum cleaner to base"""
+        print(f"{self.entity_id}|{self.domain}")
+        self.client.get_domain(self.domain).stop(entity_id=self.entity_id)
+
+    def go_home(self):
         """Return vacuum cleaner to base"""
         self.client.get_domain(self.domain).return_to_base(entity_id=self.entity_id)
 
 
-class InputBoolean(HomeAssistant):
-    """Class for input boolean"""
+class Alarm(HomeAssistant):
+    """Class for Alarm panel"""
 
     def __init__(self, entity_id: str, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.domain = "input_boolean"
+        self.domain = "alarm_control_panel"
         self.entity_id = f"{self.domain}.{entity_id}"
 
-    def turn_on(self):
-        """Turn on entity"""
-        self.client.get_domain(self.domain).turn_on(entity_id=self.entity_id)
+    def arm(self):
+        """Arm alarm panel"""
+        self.client.get_domain(self.domain).alarm_arm_away(entity_id=self.entity_id)
 
-    def turn_off(self):
-        """Turn off entity"""
-        self.client.get_domain(self.domain).turn_off(entity_id=self.entity_id)
-
-    def toggle(self):
-        """Toggle Entity"""
-        self.client.get_domain(self.domain).toggle(entity_id=self.entity_id)
+    def disarm(self):
+        """Arm alarm panel"""
+        self.client.get_domain(self.domain).alarm_disarm(entity_id=self.entity_id)
 
 
 if __name__ == "__main__":
-    testing = InputBoolean("testing")
-    testing.toggle()
-    roomba = Vacuum("vacuum")
-    roomba.stop()
-    options = Vacuum.get_functions()
-    print(options)
+    alarm = Alarm("system")
+    alarm.disarm()
