@@ -16,9 +16,10 @@ with open(f"{SCRIPT_DIR}/config/config.json", encoding="utf8") as file:
 with open(f"{CONFIG_SECRET_DIR}/.secret.json", encoding="utf8") as file:
     secret_file = json.load(file)
 
-PRINTER_HOST = config_file.get("host")
+FRONT_PRINTER_IP = config_file.get("front_printer_ip")
+BACK_PRINTER_IP = config_file.get("back_printer_ip")
 
-LS_ACCOUNT_ID = config_file.get("account_id")
+LS_ACCOUNT_ID = config_file.get("ls_account_id")
 LS_URLS = config_file.get("ls_urls")
 for urls in LS_URLS:
     LS_URLS[urls] = LS_URLS[urls].replace("{ACCOUNT_ID}", str(LS_ACCOUNT_ID))
@@ -33,12 +34,16 @@ CAM_HEIGHT = config_file.get("cam_height")
 
 SICKW_URL = config_file.get("sickw_url")
 
-DEBUG_CODE = True
+
 if config_file.get("debug_code").lower() == "false":
     DEBUG_CODE = False
-DEBUG_LOGGING = True
+else:
+    DEBUG_CODE = True
+
 if config_file.get("debug_logging").lower() == "false":
     DEBUG_LOGGING = False
+else:
+    DEBUG_LOGGING = True
 
 GOOGLE_SHEETS_SERIAL_NAME = config_file.get("google_sheets_serial_name")
 
@@ -61,6 +66,7 @@ TRELLO_APIKEY = secret_file.get("trello_apiKey")
 TRELLO_OAUTH_TOKEN = secret_file.get("trello_oauth_token")
 OPENAI_API_KEY = secret_file.get("openai_api_key")
 PHONECHECK_API_KEY = secret_file.get("phonecheck_api_key")
+HOMEASSISTANT_API_KEY = secret_file.get("homeassistant_api_key")
 
 RESPONSE_MESSAGES = [
     "Hi {name}, we are open 11-7 Tu-Sa.",
